@@ -1,34 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Quick Controls module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL3$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
 ** packaging of this file. Please review the following information to
 ** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -42,7 +45,7 @@
 
 QT_BEGIN_NAMESPACE
 
-class QQuickWheelArea : public QQuickItem
+class QQuickWheelArea1 : public QQuickItem
 {
     Q_OBJECT
     Q_PROPERTY(qreal verticalDelta READ verticalDelta WRITE setVerticalDelta NOTIFY verticalWheelMoved)
@@ -55,10 +58,11 @@ class QQuickWheelArea : public QQuickItem
     Q_PROPERTY(qreal verticalValue READ verticalValue WRITE setVerticalValue)
     Q_PROPERTY(qreal scrollSpeed READ scrollSpeed WRITE setScrollSpeed NOTIFY scrollSpeedChanged)
     Q_PROPERTY(bool active READ isActive WRITE setActive NOTIFY activeChanged)
+    Q_PROPERTY(bool inverted READ isInverted)
 
 public:
-    QQuickWheelArea(QQuickItem *parent = 0);
-    virtual ~QQuickWheelArea();
+    QQuickWheelArea1(QQuickItem *parent = 0);
+    virtual ~QQuickWheelArea1();
 
     void setHorizontalMinimumValue(qreal value);
     qreal horizontalMinimumValue() const;
@@ -89,6 +93,7 @@ public:
 
     bool isActive() const;
     void setActive(bool active);
+    bool isInverted() const;
 
 #ifndef QT_NO_WHEELEVENT
     void wheelEvent(QWheelEvent *event);
@@ -118,12 +123,13 @@ private:
     qreal m_horizontalDelta;
     qreal m_scrollSpeed;
     bool m_active;
+    bool m_inverted;
 
-    Q_DISABLE_COPY(QQuickWheelArea)
+    Q_DISABLE_COPY(QQuickWheelArea1)
 };
 
 QT_END_NAMESPACE
 
-QML_DECLARE_TYPE(QQuickWheelArea)
+QML_DECLARE_TYPE(QQuickWheelArea1)
 
 #endif // QQUICKWHEELAREA_P_H
