@@ -1,34 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the Qt Quick Controls module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL3$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
 ** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
 ** packaging of this file. Please review the following information to
 ** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl.html.
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
 ** GNU General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or later as published by the Free
-** Software Foundation and appearing in the file LICENSE.GPL included in
-** the packaging of this file. Please review the following information to
-** ensure the GNU General Public License version 2.0 requirements will be
-** met: http://www.gnu.org/licenses/gpl-2.0.html.
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -46,18 +49,18 @@
 
 QT_BEGIN_NAMESPACE
 
-QQuickMenuBase::QQuickMenuBase(QObject *parent, int type)
-    : QObject(parent), m_visible(true), m_type(static_cast<QQuickMenuItemType::MenuItemType>(type))
+QQuickMenuBase1::QQuickMenuBase1(QObject *parent, int type)
+    : QObject(parent), m_visible(true), m_type(static_cast<QQuickMenuItemType1::MenuItemType>(type))
     , m_parentMenu(0), m_container(0), m_platformItem(0), m_visualItem(0)
 {
-    if (type >= 0) {
+    if (type >= 0 && QGuiApplication::platformName() != QStringLiteral("xcb")) { // QTBUG-51372)
         m_platformItem = QGuiApplicationPrivate::platformTheme()->createPlatformMenuItem();
         if (m_platformItem)
             m_platformItem->setRole(QPlatformMenuItem::TextHeuristicRole);
     }
 }
 
-QQuickMenuBase::~QQuickMenuBase()
+QQuickMenuBase1::~QQuickMenuBase1()
 {
     if (parentMenu())
         parentMenu()->removeItem(this);
@@ -68,7 +71,7 @@ QQuickMenuBase::~QQuickMenuBase()
     }
 }
 
-void QQuickMenuBase::setVisible(bool v)
+void QQuickMenuBase1::setVisible(bool v)
 {
     if (v != m_visible) {
         m_visible = v;
@@ -82,19 +85,19 @@ void QQuickMenuBase::setVisible(bool v)
     }
 }
 
-QObject *QQuickMenuBase::parentMenuOrMenuBar() const
+QObject *QQuickMenuBase1::parentMenuOrMenuBar() const
 {
     if (!m_parentMenu)
         return parent();
     return m_parentMenu;
 }
 
-QQuickMenu *QQuickMenuBase::parentMenu() const
+QQuickMenu1 *QQuickMenuBase1::parentMenu() const
 {
     return m_parentMenu;
 }
 
-void QQuickMenuBase::setParentMenu(QQuickMenu *parentMenu)
+void QQuickMenuBase1::setParentMenu(QQuickMenu1 *parentMenu)
 {
     if (m_platformItem && m_parentMenu && m_parentMenu->platformMenu())
         m_parentMenu->platformMenu()->removeMenuItem(m_platformItem);
@@ -102,39 +105,40 @@ void QQuickMenuBase::setParentMenu(QQuickMenu *parentMenu)
     m_parentMenu = parentMenu;
 }
 
-QQuickMenuItemContainer *QQuickMenuBase::container() const
+QQuickMenuItemContainer1 *QQuickMenuBase1::container() const
 {
     return m_container;
 }
 
-void QQuickMenuBase::setContainer(QQuickMenuItemContainer *c)
+void QQuickMenuBase1::setContainer(QQuickMenuItemContainer1 *c)
 {
     m_container = c;
 }
 
-void QQuickMenuBase::syncWithPlatformMenu()
+void QQuickMenuBase1::syncWithPlatformMenu()
 {
-    QQuickMenu *menu = parentMenu();
+    QQuickMenu1 *menu = parentMenu();
     if (menu && menu->platformMenu() && platformItem()
         && menu->contains(this)) // If not, it'll be added later and then sync'ed
         menu->platformMenu()->syncMenuItem(platformItem());
 }
 
-QQuickItem *QQuickMenuBase::visualItem() const
+QQuickItem *QQuickMenuBase1::visualItem() const
 {
     return m_visualItem;
 }
 
-void QQuickMenuBase::setVisualItem(QQuickItem *item)
+void QQuickMenuBase1::setVisualItem(QQuickItem *item)
 {
     m_visualItem = item;
 }
 
 /*!
     \qmltype MenuSeparator
-    \instantiates QQuickMenuSeparator
+    \instantiates QQuickMenuSeparator1
     \inqmlmodule QtQuick.Controls
     \ingroup menus
+    \ingroup controls
     \brief MenuSeparator provides a separator for items inside a menu.
 
     \image menu.png
@@ -185,15 +189,15 @@ void QQuickMenuBase::setVisualItem(QQuickItem *item)
     This property is read-only and constant, and its value is \c MenuItemType.Separator.
 */
 
-QQuickMenuSeparator::QQuickMenuSeparator(QObject *parent)
-    : QQuickMenuBase(parent, QQuickMenuItemType::Separator)
+QQuickMenuSeparator1::QQuickMenuSeparator1(QObject *parent)
+    : QQuickMenuBase1(parent, QQuickMenuItemType1::Separator)
 {
     if (platformItem())
         platformItem()->setIsSeparator(true);
 }
 
-QQuickMenuText::QQuickMenuText(QObject *parent, QQuickMenuItemType::MenuItemType type)
-    : QQuickMenuBase(parent, type), m_action(new QQuickAction(this))
+QQuickMenuText1::QQuickMenuText1(QObject *parent, QQuickMenuItemType1::MenuItemType type)
+    : QQuickMenuBase1(parent, type), m_action(new QQuickAction1(this))
 {
     connect(m_action, SIGNAL(enabledChanged()), this, SLOT(updateEnabled()));
     connect(m_action, SIGNAL(textChanged()), this, SLOT(updateText()));
@@ -203,57 +207,57 @@ QQuickMenuText::QQuickMenuText(QObject *parent, QQuickMenuItemType::MenuItemType
     connect(m_action, SIGNAL(iconSourceChanged()), this, SIGNAL(iconSourceChanged()));
 }
 
-QQuickMenuText::~QQuickMenuText()
+QQuickMenuText1::~QQuickMenuText1()
 {
     delete m_action;
 }
 
-bool QQuickMenuText::enabled() const
+bool QQuickMenuText1::enabled() const
 {
     return action()->isEnabled();
 }
 
-void QQuickMenuText::setEnabled(bool e)
+void QQuickMenuText1::setEnabled(bool e)
 {
     action()->setEnabled(e);
 }
 
-QString QQuickMenuText::text() const
+QString QQuickMenuText1::text() const
 {
     return m_action->text();
 }
 
-void QQuickMenuText::setText(const QString &t)
+void QQuickMenuText1::setText(const QString &t)
 {
     m_action->setText(t);
 }
 
-QUrl QQuickMenuText::iconSource() const
+QUrl QQuickMenuText1::iconSource() const
 {
     return m_action->iconSource();
 }
 
-void QQuickMenuText::setIconSource(const QUrl &iconSource)
+void QQuickMenuText1::setIconSource(const QUrl &iconSource)
 {
     m_action->setIconSource(iconSource);
 }
 
-QString QQuickMenuText::iconName() const
+QString QQuickMenuText1::iconName() const
 {
     return m_action->iconName();
 }
 
-void QQuickMenuText::setIconName(const QString &iconName)
+void QQuickMenuText1::setIconName(const QString &iconName)
 {
     m_action->setIconName(iconName);
 }
 
-QIcon QQuickMenuText::icon() const
+QIcon QQuickMenuText1::icon() const
 {
     return m_action->icon();
 }
 
-void QQuickMenuText::updateText()
+void QQuickMenuText1::updateText()
 {
     if (platformItem()) {
         platformItem()->setText(text());
@@ -262,7 +266,7 @@ void QQuickMenuText::updateText()
     emit __textChanged();
 }
 
-void QQuickMenuText::updateEnabled()
+void QQuickMenuText1::updateEnabled()
 {
     if (platformItem()) {
         platformItem()->setEnabled(enabled());
@@ -271,7 +275,7 @@ void QQuickMenuText::updateEnabled()
     emit enabledChanged();
 }
 
-void QQuickMenuText::updateIcon()
+void QQuickMenuText1::updateIcon()
 {
     if (platformItem()) {
         platformItem()->setIcon(icon());
@@ -282,8 +286,9 @@ void QQuickMenuText::updateIcon()
 
 /*!
     \qmltype MenuItem
-    \instantiates QQuickMenuItem
+    \instantiates QQuickMenuItem1
     \ingroup menus
+    \ingroup controls
     \inqmlmodule QtQuick.Controls
     \brief MenuItem provides an item to add in a menu or a menu bar.
 
@@ -454,8 +459,8 @@ void QQuickMenuText::updateIcon()
     Defaults to \c null, meaning no action is bound to the menu item.
 */
 
-QQuickMenuItem::QQuickMenuItem(QObject *parent)
-    : QQuickMenuText(parent, QQuickMenuItemType::Item), m_boundAction(0)
+QQuickMenuItem1::QQuickMenuItem1(QObject *parent)
+    : QQuickMenuText1(parent, QQuickMenuItemType1::Item), m_boundAction(0)
 {
     connect(this, SIGNAL(__textChanged()), this, SIGNAL(textChanged()));
 
@@ -467,21 +472,21 @@ QQuickMenuItem::QQuickMenuItem(QObject *parent)
         connect(platformItem(), SIGNAL(activated()), this, SLOT(trigger()), Qt::QueuedConnection);
 }
 
-QQuickMenuItem::~QQuickMenuItem()
+QQuickMenuItem1::~QQuickMenuItem1()
 {
     unbindFromAction(m_boundAction);
     if (platformItem())
         disconnect(platformItem(), SIGNAL(activated()), this, SLOT(trigger()));
 }
 
-void QQuickMenuItem::setParentMenu(QQuickMenu *parentMenu)
+void QQuickMenuItem1::setParentMenu(QQuickMenu1 *parentMenu)
 {
-    QQuickMenuText::setParentMenu(parentMenu);
+    QQuickMenuText1::setParentMenu(parentMenu);
     if (parentMenu)
         connect(this, SIGNAL(triggered()), parentMenu, SLOT(updateSelectedIndex()));
 }
 
-void QQuickMenuItem::bindToAction(QQuickAction *action)
+void QQuickMenuItem1::bindToAction(QQuickAction1 *action)
 {
     m_boundAction = action;
 
@@ -509,7 +514,7 @@ void QQuickMenuItem::bindToAction(QQuickAction *action)
     }
 }
 
-void QQuickMenuItem::unbindFromAction(QObject *o)
+void QQuickMenuItem1::unbindFromAction(QObject *o)
 {
     if (!o)
         return;
@@ -517,7 +522,7 @@ void QQuickMenuItem::unbindFromAction(QObject *o)
     if (o == m_boundAction)
         m_boundAction = 0;
 
-    QQuickAction *action = qobject_cast<QQuickAction *>(o);
+    QQuickAction1 *action = qobject_cast<QQuickAction1 *>(o);
     if (!action)
         return;
 
@@ -536,14 +541,14 @@ void QQuickMenuItem::unbindFromAction(QObject *o)
     disconnect(action, SIGNAL(iconSourceChanged()), this, SIGNAL(iconSourceChanged()));
 }
 
-QQuickAction *QQuickMenuItem::action() const
+QQuickAction1 *QQuickMenuItem1::action() const
 {
     if (m_boundAction)
         return m_boundAction;
-    return QQuickMenuText::action();
+    return QQuickMenuText1::action();
 }
 
-void QQuickMenuItem::setBoundAction(QQuickAction *a)
+void QQuickMenuItem1::setBoundAction(QQuickAction1 *a)
 {
     if (a == m_boundAction)
         return;
@@ -554,50 +559,50 @@ void QQuickMenuItem::setBoundAction(QQuickAction *a)
     emit actionChanged();
 }
 
-QString QQuickMenuItem::text() const
+QString QQuickMenuItem1::text() const
 {
-    QString ownText = QQuickMenuText::text();
+    QString ownText = QQuickMenuText1::text();
     if (!ownText.isNull())
         return ownText;
     return m_boundAction ? m_boundAction->text() : QString();
 }
 
-QUrl QQuickMenuItem::iconSource() const
+QUrl QQuickMenuItem1::iconSource() const
 {
-    QUrl ownIconSource = QQuickMenuText::iconSource();
+    QUrl ownIconSource = QQuickMenuText1::iconSource();
     if (!ownIconSource.isEmpty())
         return ownIconSource;
     return m_boundAction ? m_boundAction->iconSource() : QUrl();
 }
 
-QString QQuickMenuItem::iconName() const
+QString QQuickMenuItem1::iconName() const
 {
-    QString ownIconName = QQuickMenuText::iconName();
+    QString ownIconName = QQuickMenuText1::iconName();
     if (!ownIconName.isEmpty())
         return ownIconName;
     return m_boundAction ? m_boundAction->iconName() : QString();
 }
 
-QIcon QQuickMenuItem::icon() const
+QIcon QQuickMenuItem1::icon() const
 {
-    QIcon ownIcon = QQuickMenuText::icon();
+    QIcon ownIcon = QQuickMenuText1::icon();
     if (!ownIcon.isNull())
         return ownIcon;
     return m_boundAction ? m_boundAction->icon() : QIcon();
 }
 
-QVariant QQuickMenuItem::shortcut() const
+QVariant QQuickMenuItem1::shortcut() const
 {
     return action()->shortcut();
 }
 
-void QQuickMenuItem::setShortcut(const QVariant &shortcut)
+void QQuickMenuItem1::setShortcut(const QVariant &shortcut)
 {
     if (!m_boundAction)
         action()->setShortcut(shortcut);
 }
 
-void QQuickMenuItem::updateShortcut()
+void QQuickMenuItem1::updateShortcut()
 {
     if (platformItem()) {
         QKeySequence sequence;
@@ -612,18 +617,18 @@ void QQuickMenuItem::updateShortcut()
     emit shortcutChanged();
 }
 
-bool QQuickMenuItem::checkable() const
+bool QQuickMenuItem1::checkable() const
 {
     return action()->isCheckable();
 }
 
-void QQuickMenuItem::setCheckable(bool checkable)
+void QQuickMenuItem1::setCheckable(bool checkable)
 {
     if (!m_boundAction)
         action()->setCheckable(checkable);
 }
 
-void QQuickMenuItem::updateCheckable()
+void QQuickMenuItem1::updateCheckable()
 {
     if (platformItem()) {
         platformItem()->setCheckable(checkable());
@@ -633,18 +638,18 @@ void QQuickMenuItem::updateCheckable()
     emit checkableChanged();
 }
 
-bool QQuickMenuItem::checked() const
+bool QQuickMenuItem1::checked() const
 {
     return action()->isChecked();
 }
 
-void QQuickMenuItem::setChecked(bool checked)
+void QQuickMenuItem1::setChecked(bool checked)
 {
     if (!m_boundAction)
         action()->setChecked(checked);
 }
 
-void QQuickMenuItem::updateChecked()
+void QQuickMenuItem1::updateChecked()
 {
     bool checked = this->checked();
     if (platformItem()) {
@@ -655,26 +660,31 @@ void QQuickMenuItem::updateChecked()
     emit toggled(checked);
 }
 
-QQuickExclusiveGroup *QQuickMenuItem::exclusiveGroup() const
+QQuickExclusiveGroup1 *QQuickMenuItem1::exclusiveGroup() const
 {
     return action()->exclusiveGroup();
 }
 
-void QQuickMenuItem::setExclusiveGroup(QQuickExclusiveGroup *eg)
+void QQuickMenuItem1::setExclusiveGroup(QQuickExclusiveGroup1 *eg)
 {
     if (!m_boundAction)
         action()->setExclusiveGroup(eg);
 }
 
-void QQuickMenuItem::setEnabled(bool enabled)
+void QQuickMenuItem1::setEnabled(bool enabled)
 {
     if (!m_boundAction)
         action()->setEnabled(enabled);
 }
 
-void QQuickMenuItem::trigger()
+void QQuickMenuItem1::trigger()
 {
+    QPointer<QQuickMenu1> menu(parentMenu());
+    if (menu)
+        menu->prepareItemTrigger(this);
     action()->trigger(this);
+    if (menu)
+        menu->concludeItemTrigger(this);
 }
 
 QT_END_NAMESPACE
